Summary:	Java Simple Serial Connector
Name:		jssc
Version:	2.8.0
Release:	%mkrel 8
License:	GPLv3+
Group:		Development/Java
URL:		http://jssc.scream3r.org
Source:		https://github.com/scream3r/java-simple-serial-connector/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# lack of license file, reported upstream:
# https://github.com/scream3r/java-simple-serial-connector/issues/79
Source1:	https://www.gnu.org/licenses/gpl-3.0.txt
# jni load library patch
Patch0:		%{name}-loadlibrary.patch
# fixes jni header mismatch, reported upstream:
# https://github.com/scream3r/java-simple-serial-connector/issues/80
Patch1:		%{name}-jni-fix.patch

BuildRequires:	java-devel
BuildRequires:	javapackages-local

Requires:	java-headless
Requires:	jpackage-utils

%global jni		%{_libdir}/%{name}
%global jniFullSoName	libjSSC-%{version}.so
%global jniSoName	libjSSC.so

%description
jSSC (Java Simple Serial Connector) - library for working with serial ports
from Java.

%package javadoc
Summary:        Javadoc for %{name} package
BuildArch:      noarch
Requires:       %{name} = %{version}


%description javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q -n java-simple-serial-connector-%{version}
%patch0 -p1 -b .loadlibrary
%patch1 -p1 -b .jni-fix
cp -a %{SOURCE1} COPYING
# remove prebuild binaries and jni headers
rm -rf src/java/libs
rm -rf src/cpp/*.h

%build
# compile classes
mkdir -p classes/
(cd src/java; javac -h ../cpp -d ../../classes/ -encoding UTF-8 jssc/*.java)
(cd classes; jar -cf ../jssc.jar jssc/*.class)
# generate javadoc
mkdir -p javadoc/
(cd src/java; javadoc -Xdoclint:none -d ../../javadoc/ -encoding UTF-8 jssc/*.java)
# compile native library
g++ %{optflags} %{?__global_ldflags} -fPIC -shared \
    -D jSSC_NATIVE_LIB_VERSION=\"$(echo %{version} | sed 's/\([1-9]\.[0-9]\).*/\1/')\" \
    -I %{java_home}/include \
    -I %{java_home}/include/linux \
    -o %{jniFullSoName} src/cpp/_nix_based/jssc.cpp


%install
# create necessary directories
install -d %{buildroot}%{jni} \
           %{buildroot}%{_javadocdir}/%{name}
# install jni library and symlink
install -m 0755 -p %{jniFullSoName} %{buildroot}%{jni}
ln -srf %{buildroot}%{jni}/%{jniFullSoName} %{buildroot}%{jni}/%{jniSoName}
# install jar, pom files and java docs
%mvn_artifact org.scream3r:%{name}:%{version} %{name}.jar
%mvn_file org.scream3r:%{name}:%{version} %{name}
%mvn_install -J javadoc


%files -f .mfiles
%license COPYING
%doc README.txt
%{jni}/


%files javadoc
%doc %{_javadocdir}/%{name}


%changelog
* Sat Mar 26 2022 umeabot <umeabot> 2.8.0-8.mga9
+ Revision: 1828387
- Mageia 9 Mass Rebuild

* Thu Dec 17 2020 neoclust <neoclust> 2.8.0-7.mga8
+ Revision: 1660487
- Fix build

* Thu Feb 13 2020 umeabot <umeabot> 2.8.0-6.mga8
+ Revision: 1513689
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.8.0-5.mga7
+ Revision: 1298400
- Mageia 7 Mass Rebuild

* Tue Sep 12 2017 daviddavid <daviddavid> 2.8.0-4.mga7
+ Revision: 1153191
- sync with fc27
+ tv <tv>
- add build fixes from FC
- BR java-devel instead of gcj

* Mon Mar 28 2016 pterjan <pterjan> 2.8.0-3.mga6
+ Revision: 995980
- Rebuild to get it on arm

* Sat Feb 20 2016 umeabot <umeabot> 2.8.0-2.mga6
+ Revision: 971754
- Mageia 6 Mass Rebuild

* Thu Sep 10 2015 ycantin <ycantin> 2.8.0-1.mga6
+ Revision: 875688
- imported package jssc

